package com.ruoyi.postCheck.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.postCheck.domain.PostPlanCheckUser;
import com.ruoyi.postCheck.service.IPostPlanCheckUserService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiImplicitParam;

/**
 * 岗检计划明细检查人表Controller
 *
 * @author csg
 * @date 2023-12-19
 */
@Api(tags = "2.3.3-岗检计划明细检查人表接口（废弃）")
@RestController
@RequestMapping("/postCheck/planInfoUser")
public class PostPlanCheckUserController extends BaseController
{
    @Autowired
    private IPostPlanCheckUserService postPlanInfoUserService;

    /**
     * 查询岗检计划明细检查人表列表
     */
    @ApiOperation("查询岗检计划明细检查人表列表")
    @PreAuthorize("@ss.hasPermi('postCheck:planInfoUser:list')")
    @GetMapping("/list")
    public TableDataInfo list(PostPlanCheckUser postPlanCheckUser)
    {
        startPage();
        List<PostPlanCheckUser> list = postPlanInfoUserService.selectPostPlanInfoUserList(postPlanCheckUser);
        return getDataTable(list);
    }

    /**
     * 导出岗检计划明细检查人表列表
     */
    @ApiOperation("导出岗检计划明细检查人表列表")
    @PreAuthorize("@ss.hasPermi('postCheck:planInfoUser:export')")
    @Log(title = "岗检计划明细检查人表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PostPlanCheckUser postPlanCheckUser)
    {
        List<PostPlanCheckUser> list = postPlanInfoUserService.selectPostPlanInfoUserList(postPlanCheckUser);
        ExcelUtil<PostPlanCheckUser> util = new ExcelUtil<PostPlanCheckUser>(PostPlanCheckUser.class);
        util.exportExcel(response, list, "岗检计划明细检查人表数据");
    }

    /**
     * 获取岗检计划明细检查人表详细信息
     */
    @ApiOperation("获取岗检计划明细检查人表详细信息")
    @PreAuthorize("@ss.hasPermi('postCheck:planInfoUser:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(postPlanInfoUserService.selectPostPlanInfoUserById(id));
    }

    /**
     * 新增岗检计划明细检查人表
     */
    @ApiOperation("新增岗检计划明细检查人表")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "主键", dataType = "Long", dataTypeClass = Long.class),
        @ApiImplicitParam(name = "postPlanInfoId", value = "计划明细ID", dataType = "Long", dataTypeClass = Long.class),
        @ApiImplicitParam(name = "checkedUserId", value = "检查人员ID", dataType = "Long", dataTypeClass = Long.class),
        @ApiImplicitParam(name = "delFlag", value = "del_flag", dataType = "Integer", dataTypeClass = Integer.class),
        @ApiImplicitParam(name = "createUserId", value = "创建者用户ID", dataType = "Long", dataTypeClass = Long.class),
        @ApiImplicitParam(name = "type", value = "检查人员ID：1-组长；2-组员；", dataType = "Integer", dataTypeClass = Integer.class),
    })
    @PreAuthorize("@ss.hasPermi('postCheck:planInfoUser:add')")
    @Log(title = "岗检计划明细检查人表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PostPlanCheckUser postPlanCheckUser)
    {
        return toAjax(postPlanInfoUserService.insertPostPlanInfoUser(postPlanCheckUser));
    }

    /**
     * 修改岗检计划明细检查人表
     */
    @ApiOperation("修改岗检计划明细检查人表")
    @PreAuthorize("@ss.hasPermi('postCheck:planInfoUser:edit')")
    @Log(title = "岗检计划明细检查人表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PostPlanCheckUser postPlanCheckUser)
    {
        return toAjax(postPlanInfoUserService.updatePostPlanInfoUser(postPlanCheckUser));
    }

    /**
     * 删除岗检计划明细检查人表
     */
    @ApiOperation("删除岗检计划明细检查人表")
    @PreAuthorize("@ss.hasPermi('postCheck:planInfoUser:remove')")
    @Log(title = "岗检计划明细检查人表", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(postPlanInfoUserService.deletePostPlanInfoUserByIds(ids));
    }
}
